This module was written not with the intent of writing fancy, good looking or effective code. The main intent was to write an easy-to-use module that DevNet beginners would benefit of using in order to make scripts for deployment and network management. The idea started within a customer project, hence the functions are limited to what have been used so far. For feature request, ideas or questions feel free to reach out. ccie60702@gmail.com